==> duckplyr_0.3.0.tar.gz: duckplyr/tests/testthat/_snaps/tpch.md <==
# TPCH queries can be parsed and run

    Code
      tpch_01()
    Output
      # A tibble: 0 x 10
      # i 10 variables: l_returnflag <chr>, l_linestatus <chr>, sum_qty <dbl>,
      #   sum_base_price <dbl>, sum_disc_price <dbl>, sum_charge <dbl>,
      #   avg_qty <dbl>, avg_price <dbl>, avg_disc <dbl>, count_order <int>
    Code
      tpch_02()
    Output
      # A tibble: 0 x 8
      # i 8 variables: s_acctbal <dbl>, s_name <chr>, n_name <chr>, p_partkey <int>,
      #   p_mfgr <chr>, s_address <chr>, s_phone <chr>, s_comment <chr>
    Code
      tpch_03()
    Output
      # A tibble: 0 x 4
      # i 4 variables: l_orderkey <int>, revenue <dbl>, o_orderdate <date>,
      #   o_shippriority <int>
    Code
      tpch_04()
    Output
      # A tibble: 0 x 2
      # i 2 variables: o_orderpriority <chr>, order_count <int>
    Code
      tpch_05()
    Output
      # A tibble: 0 x 2
      # i 2 variables: n_name <chr>, revenue <dbl>
    Code
      tpch_06()
    Output
      # A tibble: 1 x 1
        revenue
          <dbl>
      1      NA
    Code
      tpch_07()
    Output
      # A tibble: 0 x 4
      # i 4 variables: supp_nation <chr>, cust_nation <chr>, l_year <int>,
      #   revenue <dbl>
    Code
      tpch_08()
    Output
      # A tibble: 0 x 2
      # i 2 variables: o_year <int>, mkt_share <dbl>
    Code
      tpch_09()
    Output
      # A tibble: 0 x 3
      # i 3 variables: nation <chr>, o_year <int>, sum_profit <dbl>
    Code
      tpch_10()
    Output
      # A tibble: 0 x 8
      # i 8 variables: c_custkey <int>, c_name <chr>, revenue <dbl>, c_acctbal <dbl>,
      #   n_name <chr>, c_address <chr>, c_phone <chr>, c_comment <chr>
    Code
      tpch_11()
    Output
      # A tibble: 0 x 2
      # i 2 variables: ps_partkey <int>, value <dbl>
    Code
      tpch_12()
    Output
      # A tibble: 0 x 3
      # i 3 variables: l_shipmode <chr>, high_line_count <dbl>, low_line_count <dbl>
    Code
      tpch_13()
    Output
      # A tibble: 0 x 2
      # i 2 variables: c_count <dbl>, custdist <int>
    Code
      tpch_14()
    Output
      # A tibble: 1 x 1
        promo_revenue
                <dbl>
      1            NA
    Code
      tpch_15()
    Output
      # A tibble: 0 x 5
      # i 5 variables: s_suppkey <int>, s_name <chr>, s_address <chr>, s_phone <chr>,
      #   total_revenue <dbl>
    Code
      tpch_16()
    Output
      # A tibble: 0 x 4
      # i 4 variables: p_brand <chr>, p_type <chr>, p_size <int>, supplier_cnt <dbl>
    Code
      tpch_17()
    Output
      # A tibble: 1 x 1
        avg_yearly
             <dbl>
      1         NA
    Code
      tpch_18()
    Output
      # A tibble: 0 x 6
      # i 6 variables: c_name <chr>, c_custkey <int>, o_orderkey <int>,
      #   o_orderdate <date>, o_totalprice <dbl>, sum <dbl>
    Code
      tpch_19()
    Output
      # A tibble: 1 x 1
        revenue
          <dbl>
      1      NA
    Code
      tpch_20()
    Output
      # A tibble: 0 x 2
      # i 2 variables: s_name <chr>, s_address <chr>
    Code
      tpch_21()
    Output
      # A tibble: 0 x 2
      # i 2 variables: s_name <chr>, numwait <int>
    Code
      tpch_22()
    Output
      # A tibble: 0 x 3
      # i 3 variables: cntrycode <chr>, numcust <int>, totacctbal <dbl>

==> duckplyr_1.1.2.tar.gz: duckplyr/tests/testthat/_snaps/tpch.md <==
# TPCH queries can be parsed and run

    Code
      tpch_01()
    Output
      # A duckplyr data frame: 10 variables
      # i 10 variables: l_returnflag <chr>, l_linestatus <chr>, sum_qty <dbl>,
      #   sum_base_price <dbl>, sum_disc_price <dbl>, sum_charge <dbl>,
      #   avg_qty <dbl>, avg_price <dbl>, avg_disc <dbl>, count_order <int>
    Code
      tpch_02()
    Output
      # A duckplyr data frame: 8 variables
      # i 8 variables: s_acctbal <dbl>, s_name <chr>, n_name <chr>, p_partkey <int>,
      #   p_mfgr <chr>, s_address <chr>, s_phone <chr>, s_comment <chr>
    Code
      tpch_03()
    Output
      # A duckplyr data frame: 4 variables
      # i 4 variables: l_orderkey <int>, revenue <dbl>, o_orderdate <date>,
      #   o_shippriority <int>
    Code
      tpch_04()
    Output
      # A duckplyr data frame: 2 variables
      # i 2 variables: o_orderpriority <chr>, order_count <int>
    Code
      tpch_05()
    Output
      # A duckplyr data frame: 2 variables
      # i 2 variables: n_name <chr>, revenue <dbl>
    Code
      tpch_06()
    Output
      # A duckplyr data frame: 1 variable
        revenue
          <dbl>
      1      NA
    Code
      tpch_07()
    Output
      # A duckplyr data frame: 4 variables
      # i 4 variables: supp_nation <chr>, cust_nation <chr>, l_year <int>,
      #   revenue <dbl>
    Code
      tpch_08()
    Output
      # A duckplyr data frame: 2 variables
      # i 2 variables: o_year <int>, mkt_share <dbl>
    Code
      tpch_09()
    Output
      # A duckplyr data frame: 3 variables
      # i 3 variables: nation <chr>, o_year <int>, sum_profit <dbl>
    Code
      tpch_10()
    Output
      # A duckplyr data frame: 8 variables
      # i 8 variables: c_custkey <int>, c_name <chr>, revenue <dbl>, c_acctbal <dbl>,
      #   n_name <chr>, c_address <chr>, c_phone <chr>, c_comment <chr>
    Code
      tpch_11()
    Output
      # A duckplyr data frame: 2 variables
      # i 2 variables: ps_partkey <int>, value <dbl>
    Code
      tpch_12()
    Output
      # A duckplyr data frame: 3 variables
      # i 3 variables: l_shipmode <chr>, high_line_count <dbl>, low_line_count <dbl>
    Code
      tpch_13()
    Output
      # A duckplyr data frame: 2 variables
      # i 2 variables: c_count <dbl>, custdist <int>
    Code
      tpch_14()
    Output
      # A duckplyr data frame: 1 variable
        promo_revenue
                <dbl>
      1            NA
    Code
      tpch_15()
    Output
      # A duckplyr data frame: 5 variables
      # i 5 variables: s_suppkey <int>, s_name <chr>, s_address <chr>, s_phone <chr>,
      #   total_revenue <dbl>
    Code
      tpch_16()
    Output
      # A duckplyr data frame: 4 variables
      # i 4 variables: p_brand <chr>, p_type <chr>, p_size <int>, supplier_cnt <dbl>
    Code
      tpch_17()
    Output
      # A duckplyr data frame: 1 variable
        avg_yearly
             <dbl>
      1         NA
    Code
      tpch_18()
    Output
      # A duckplyr data frame: 6 variables
      # i 6 variables: c_name <chr>, c_custkey <int>, o_orderkey <int>,
      #   o_orderdate <date>, o_totalprice <dbl>, sum <dbl>
    Code
      tpch_19()
    Output
      # A duckplyr data frame: 1 variable
        revenue
          <dbl>
      1      NA
    Code
      tpch_20()
    Output
      # A duckplyr data frame: 2 variables
      # i 2 variables: s_name <chr>, s_address <chr>
    Code
      tpch_21()
    Output
      # A duckplyr data frame: 2 variables
      # i 2 variables: s_name <chr>, numwait <int>
    Code
      tpch_22()
    Output
      # A duckplyr data frame: 3 variables
      # i 3 variables: cntrycode <chr>, numcust <int>, totacctbal <dbl>
